ItemPayload<Section, Item> class final

Inheritance

Constructors

ItemPayload(Item value)
const

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value → Item
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
Compares the wrapped item value, NOT wrapper identity. See the rationale on SectionPayload.==.
override