runBatch<T> method

T runBatch<T>(
  1. T body()
)

Coalesces structural notifications across the mutations performed inside body into a single post-batch refresh. Payload notifications are also coalesced and deduped by key. Delegates to the underlying TreeController.runBatch.

Implementation

T runBatch<T>(T Function() body) {
  _checkNotDisposed();
  return _tree.runBatch<T>(body);
}