sectioned_sliver_list/sectioned_sliver_list library

SectionedSliverList — header + items convenience sliver.

Classes

ItemInput<IKey, Item>
ItemView<SKey, IKey, Section, Item>
Rich view of a visible item passed to an item builder.
SectionedListController<SKey, IKey, Section, Item>
Controller for a SectionedSliverList.
SectionedSliverList<SKey, IKey, Section, Item>
SectionedSliverListState<SKey, IKey, Section, Item>
SectionInput<SKey, IKey, Section, Item>
SectionView<SKey, IKey, Section, Item>
Rich view of a visible section header passed to a header builder.

Typedefs

SectionHeaderBuilder<SKey, IKey, Section, Item> = Widget Function(BuildContext context, SectionView<SKey, IKey, Section, Item> view)
Builds a header widget for a visible section.
SectionItemBuilder<SKey, IKey, Section, Item> = Widget Function(BuildContext context, ItemView<SKey, IKey, Section, Item> view)
Builds a row widget for a visible item.