controller property
The controller backing this view, available as an escape hatch. Convenience methods on this view delegate to the controller.
Implementation
final SectionedListController<K, Section, Item> controller;
The controller backing this view, available as an escape hatch. Convenience methods on this view delegate to the controller.
final SectionedListController<K, Section, Item> controller;