operator [] method
Forward lookup: returns the nid for key, or null if key is not
registered. Matches the API of the underlying Map<TKey, int>.
Implementation
int? operator [](TKey key) {
return _keyToNid[key];
}
Forward lookup: returns the nid for key, or null if key is not
registered. Matches the API of the underlying Map<TKey, int>.
int? operator [](TKey key) {
return _keyToNid[key];
}