childListOf method
Child key list for key, or null when key has no list allocated yet
(or is unregistered).
Implementation
List<TKey>? childListOf(TKey key) {
final nid = nids[key];
return nid == null ? null : _childrenByNid[nid];
}
Child key list for key, or null when key has no list allocated yet
(or is unregistered).
List<TKey>? childListOf(TKey key) {
final nid = nids[key];
return nid == null ? null : _childrenByNid[nid];
}