childListOrCreate method
Child key list for key, allocating an empty list when none exists.
key must be registered.
Implementation
List<TKey> childListOrCreate(TKey key) {
final nid = nids[key]!;
return _childrenByNid[nid] ??= <TKey>[];
}
Child key list for key, allocating an empty list when none exists.
key must be registered.
List<TKey> childListOrCreate(TKey key) {
final nid = nids[key]!;
return _childrenByNid[nid] ??= <TKey>[];
}