rebindController method

void rebindController(
  1. TreeController<TKey, TData> controller
)

Re-binds the registry to a new controller on RenderSliverTree's controller setter. Caller separately calls reset to drop any state staged against the old controller's keys.

Implementation

void rebindController(TreeController<TKey, TData> controller) {
  ghosts.rebindController(controller);
}