TreeChildManager<TKey> class abstract

Interface for managing child render objects in RenderSliverTree.

Implemented by SliverTreeElement to allow the render object to request child creation/removal during layout.

Implementers

Constructors

TreeChildManager()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createChild(TKey nodeId) → void
Creates or updates the child for the given node.
didFinishLayout() → void
Called when layout finishes.
didStartLayout() → void
Called when layout starts.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeChild(TKey nodeId) → void
Removes the child for the given node.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited