maxStickyDepth property
How many depth levels of headers should stick to the top.
0 means no sticky headers. 1 means root nodes stick, etc.
Implementation
final int maxStickyDepth;
How many depth levels of headers should stick to the top.
0 means no sticky headers. 1 means root nodes stick, etc.
final int maxStickyDepth;