childCount property
int
get
childCount
Number of direct children currently attached to this node.
Implementation
int get childCount {
return controller.getChildCount(key);
}
Number of direct children currently attached to this node.
int get childCount {
return controller.getChildCount(key);
}