operator [] method
TItem?
operator [](
- TKey key
Gets the payload for key, or null if missing.
Implementation
TItem? operator [](TKey key) {
return dataByKey[key];
}
Gets the payload for key, or null if missing.
TItem? operator [](TKey key) {
return dataByKey[key];
}