captureOperationGroupToken method

Object? captureOperationGroupToken(
  1. TKey operationKey
)

Captures an opaque token identifying the current operation group at operationKey, or null if no group is installed there.

Implementation

Object? captureOperationGroupToken(TKey operationKey) =>
    _opGroupAt(operationKey);