getAnimationState method

AnimationState? getAnimationState(
  1. TKey key
)

Gets the animation state for a node, or null if not animating. Returns the standalone state if present, a synthetic entering state for operation group members that are expanding, or null for bulk/ collapsing groups.

Implementation

AnimationState? getAnimationState(TKey key) => _anim.getAnimationState(key);