getChildCount method
Gets the number of children for the given node.
Implementation
int getChildCount(TKey key) {
return _childListOf(key)?.length ?? 0;
}
Gets the number of children for the given node.
int getChildCount(TKey key) {
return _childListOf(key)?.length ?? 0;
}