getChildren method

List<TKey> getChildren(
  1. TKey key
)

Gets the ordered list of child keys for the given node.

Returns an empty list if the node has no children or doesn't exist.

Implementation

List<TKey> getChildren(TKey key) {
  final c = _childListOf(key);
  if (c == null || c.isEmpty) return const [];
  return UnmodifiableListView<TKey>(c);
}