getCurrentExtent method
Gets the current extent for a node, accounting for animation.
Implementation
double getCurrentExtent(TKey key) => _anim.getCurrentExtent(key);
Gets the current extent for a node, accounting for animation.
double getCurrentExtent(TKey key) => _anim.getCurrentExtent(key);