getParent method
TKey?
getParent(
- TKey key
Gets the parent key for the given node, or null if it is a root.
Implementation
TKey? getParent(TKey key) => _parentKeyOfKey(key);
Gets the parent key for the given node, or null if it is a root.
TKey? getParent(TKey key) => _parentKeyOfKey(key);