TreeDropZone enum

Where the pointer lies relative to a candidate drop-target row.

Inheritance
Available extensions

Values

above → const TreeDropZone

Insert the dragged node as a sibling above TreeDropTarget.targetKey.

into → const TreeDropZone

Insert the dragged node as the first child of TreeDropTarget.targetKey.

below → const TreeDropZone

Insert the dragged node as a sibling below TreeDropTarget.targetKey.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<TreeDropZone>
A constant List of the values in this enum, in order of their declaration.