sliver_tree/_sync_helpers library
Internal sync-time helpers shared by widgets that drive a TreeController through a TreeSyncController. Not exported from the package barrel.
Functions
-
expandParentsThatGainedChildren<
TKey, TData> ({required TreeController< TKey, TData> controller, required Map<TKey, List< oldChildrenByParent, required Map<TKey> >TKey, List< newChildrenByParent, required Set<TKey> >TKey> rememberedBeforeSync, required bool animate}) → void - Auto-expands parents whose first children appeared in the most recent sync.