controller property
The backing tree controller.
Most callers should rely on the richer convenience properties on this view, but the controller remains available as an escape hatch.
Implementation
final TreeController<TKey, TItem> controller;
The backing tree controller.
Most callers should rely on the richer convenience properties on this view, but the controller remains available as an escape hatch.
final TreeController<TKey, TItem> controller;