getCurrentExtent method
Gets the current extent for a node, accounting for animation.
Implementation
double getCurrentExtent(TKey key) {
return getAnimatedExtent(key, _fullExtentOf(key) ?? defaultExtent);
}
Gets the current extent for a node, accounting for animation.
double getCurrentExtent(TKey key) {
return getAnimatedExtent(key, _fullExtentOf(key) ?? defaultExtent);
}