getEstimatedExtent method
Gets the estimated full extent for a node.
Returns the cached measured extent if available, otherwise defaultExtent.
Implementation
double getEstimatedExtent(TKey key) {
return _fullExtentOf(key) ?? defaultExtent;
}
Gets the estimated full extent for a node.
Returns the cached measured extent if available, otherwise defaultExtent.
double getEstimatedExtent(TKey key) {
return _fullExtentOf(key) ?? defaultExtent;
}