isBulkAnimating property
bool
get
isBulkAnimating
True when a bulk animation group is currently active and has members animating in either direction.
Used by the render object to gate its scalar-offset fast path.
Implementation
bool get isBulkAnimating {
final g = _bulkAnimationGroup;
if (g == null) return false;
return g.members.isNotEmpty || g.pendingRemoval.isNotEmpty;
}