TreeNodeBuilder<TKey, TData> class
A widget that listens to a TreeController but only rebuilds when the
specified node's hasChildren or isExpanded state changes.
Example:
TreeNodeBuilder<String, MyData>(
controller: controller,
nodeId: path,
builder: (context, hasChildren, isExpanded) {
if (hasChildren) {
return IconButton(
icon: Icon(isExpanded ? Icons.expand_less : Icons.expand_more),
onPressed: () => controller.toggle(path),
);
}
return const SizedBox.shrink();
},
)
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- TreeNodeBuilder
Constructors
-
TreeNodeBuilder({required TreeController<
TKey, TData> controller, required TKey nodeId, required Widget builder(BuildContext context, bool hasChildren, bool isExpanded), Key? key}) -
Creates a tree node builder.
const
Properties
- builder → Widget Function(BuildContext context, bool hasChildren, bool isExpanded)
-
Builder called with the node's current state.
final
-
controller
→ TreeController<
TKey, TData> -
The controller to listen to.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- nodeId → TKey
-
The node ID to track.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< TreeNodeBuilder< TKey, TData> > -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited