SliverTreeParentData class
Parent data for children of RenderSliverTree.
Stores layout information computed during RenderSliverTree.performLayout.
- Inheritance
-
- Object
- ParentData
- SliverTreeParentData
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- indent ↔ double
-
Horizontal indent based on node depth.
getter/setter pair
- layoutOffset ↔ double
-
Offset from the start of the sliver's scroll extent.
getter/setter pair
- nodeId ↔ Object?
-
The node ID this child represents.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- visibleExtent ↔ double
-
The visible extent (height) of this child, accounting for animation.
May be less than the child's actual size during enter/exit animations.
getter/setter pair
Methods
-
detach(
) → void -
Called when the RenderObject is removed from the tree.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited