StickyHeaderInfo<TKey> class

Computed sticky header position for a single node.

Created during layout, consumed during paint and hit-test.

Constructors

StickyHeaderInfo({required TKey nodeId, required double pinnedY, required double extent, required double indent})

Properties

extent double
Full (non-animated) extent of the header.
final
hashCode int
The hash code for this object.
no setterinherited
indent double
Horizontal indent for this header's depth.
final
nodeId → TKey
The node ID of the sticky header.
final
pinnedY double
Y offset relative to the viewport top where this header paints.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited